@@ -231,7 +231,7 @@ static inline int sb_integer(SEXP x) {
 static void * (*const volatile secure_memset)(void *, int, size_t) = memset;
 #endif
 
-inline void sb_clear_buffer(void *buf, size_t sz) {
+inline void sb_clear_buffer(void *buf, const size_t sz) {
 #ifdef MBEDTLS_CT_ASM
   memset(buf, 0, sz);
   asm volatile ("" ::: "memory");
@@ -276,14 +276,14 @@ static void hash_object(mbedtls_sha3_context *ctx, const SEXP x) {
   
   switch (TYPEOF(x)) {
   case STRSXP:
-    if (XLENGTH(x) == 1 && ATTRIB(x) == R_NilValue) {
+    if (XLENGTH(x) == 1 && !ANY_ATTRIB(x)) {
       const char *s = SB_STRING(x);
       mbedtls_sha3_update(ctx, (uint8_t *) s, strlen(s));
       return;
     }
     break;
   case RAWSXP:
-    if (ATTRIB(x) == R_NilValue) {
+    if (!ANY_ATTRIB(x)) {
       mbedtls_sha3_update(ctx, (uint8_t *) DATAPTR_RO(x), (size_t) XLENGTH(x));
       return;
     }
@@ -309,7 +309,7 @@ static void hash_object(mbedtls_sha3_context *ctx, const SEXP x) {
   
 }
 
-SEXP sb_hash_sexp(unsigned char *buf, size_t sz, int conv) {
+SEXP sb_hash_sexp(unsigned char *buf, const size_t sz, const int conv) {
   
   SEXP out;
   if (conv == 0) {
